
# Slot: deprecated element has possible replacement


When an element is deprecated, it can be potentially replaced by this uri or curie

URI: [linkml:deprecated_element_has_possible_replacement](https://w3id.org/linkml/deprecated_element_has_possible_replacement)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | OIO:consider |

